/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ApplicationFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.util.Vector;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with application fields.
 * @author skabore
 */
public class ApplicationFrame extends JPanel {

    /**
     * Uid.
     */
    private static final long serialVersionUID = -874213090164317644L;

    /**
     * The content panel.
     */
    private final JPanel contentPanel;

    /**
     * The icon label.
     */
    private final JLabel iconLabel;

    /**
     * The error label.
     */
    private JLabel errorLabel;

    /**
     * The separator.
     */
    private final JSeparator separator;

    /**
     * The text label.
     */
    private final JLabel textLabel;

    /**
     * The title panel.
     */
    private final JPanel titlePanel;

    /**
     * The application path radioButton.
     */
    private JRadioButton pathRadioButton;

    /**
     * The application url radioButton.
     */
    private JRadioButton urlRadioButton;

    /**
     * The application path.
     */
    private JTextField applicationPath;

    /**
     * The application url.
     */
    private JTextField applicationUrl;

    /**
     * The browseApplication button.
     */
    private JButton jbBrowseAppli;

    /**
     * The addApplication button.
     */
    private JButton jbAdd;

    /**
     * The deleteApplication button.
     */
    private JButton jbDelete;

    /**
     * The application list.
     */
    private JList applicationList;

    /**
     * The application item.
     */
    private Vector<String> applicationsItems;

    /**
     * The constructor.
     * @param starter the starter librairy
     * @param steps, the required steps to create a starter
     * @param stepId, the sted number
     */
    public ApplicationFrame(final int steps, final int stepId) {
        super();

        contentPanel = getContentPanel();
        contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        titlePanel = new JPanel();
        textLabel = new JLabel();
        iconLabel = new JLabel();
        separator = new JSeparator();

        setLayout(new BorderLayout());

        titlePanel.setLayout(new java.awt.BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Application(s) to deploy");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);
        if (icon != null) {
            iconLabel.setIcon(icon);
        }
        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel(stepId + "/" + steps + "  "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel(new BorderLayout());
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel(new BorderLayout());
        JPanel notePanel = new JPanel(new SpringLayout());
        JPanel fields = new JPanel(new GridLayout(2, 2));
        JPanel fieldsPanel = new JPanel(new BorderLayout());
        JPanel applicationPanel = new JPanel(new SpringLayout());
        JPanel applicationListPanel = new JPanel(new BorderLayout());

        JPanel applicationFieldPanel = new JPanel(new SpringLayout());
        JPanel appliField = new JPanel(new BorderLayout());
        JPanel buttonPanel = new JPanel();

        pathRadioButton = new JRadioButton("Path ");
        urlRadioButton = new JRadioButton("URL ");
        ButtonGroup groupCopy = new ButtonGroup();
        groupCopy.add(pathRadioButton);
        pathRadioButton.setSelected(true);
        groupCopy.add(urlRadioButton);

        applicationPath = new JTextField(20);
        applicationUrl = new JTextField(20);
        applicationUrl.setEditable(false);

        jbBrowseAppli = new JButton("Browse...");
        jbAdd = new JButton("Add");
        jbDelete = new JButton("Delete");

        errorLabel = new JLabel();
        errorLabel.setForeground(Color.red);

        notePanel.add(new JLabel("Choose \"Path\" to copy application(s)" + " from disk, or \"URL\" to download application(s)"
                + " from website."));
        notePanel.add(new JLabel(" "));
        notePanel.add(new JLabel("You can select many applications. Example:"
                + " path-of-application1;path-of-application2;...;" + "path-of-applicationN"));
        notePanel.add(new JLabel(" "));
        SpringUtilities.makeCompactGrid(notePanel, 4, 1, 6, 0, 6, 0);

        appliField.add(applicationPath, BorderLayout.CENTER);
        appliField.add(jbBrowseAppli, BorderLayout.EAST);

        applicationFieldPanel.add(pathRadioButton);
        applicationFieldPanel.add(appliField);
        applicationFieldPanel.add(urlRadioButton);
        applicationFieldPanel.add(applicationUrl);
        SpringUtilities.makeCompactGrid(applicationFieldPanel, 2, 2, 6, 6, 6, 6);

        buttonPanel.add(jbAdd);
        buttonPanel.add(jbDelete);

        fields.add(applicationFieldPanel);
        fields.add(buttonPanel);
        fieldsPanel.add(fields, BorderLayout.NORTH);

        applicationsItems = new Vector<String>();
        applicationList = new JList(applicationsItems);
        JScrollPane applicationPane = new JScrollPane(applicationList);
        applicationPane.setPreferredSize(new Dimension(400, 400));
        applicationListPanel.add(new JLabel("List of applications "), BorderLayout.NORTH);
        applicationListPanel.add(applicationPane, BorderLayout.CENTER);
        applicationPanel.add(fieldsPanel);
        applicationPanel.add(applicationListPanel);
        SpringUtilities.makeCompactGrid(applicationPanel, 1, 2, 6, 0, 6, 0);
        contentPanel1.add(notePanel, BorderLayout.NORTH);
        contentPanel1.add(applicationPanel, BorderLayout.CENTER);
        contentPanel1.add(errorLabel, BorderLayout.SOUTH);
        return contentPanel1;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return applicationPath.
     */
    public JTextField getApplicationPath() {
        return applicationPath;
    }

    /**
     * @return applicationUrl.
     */
    public JTextField getApplicationUrl() {
        return applicationUrl;
    }

    /**
     * @return jbAdd.
     */
    public JButton getJbAdd() {
        return jbAdd;
    }

    /**
     * @return jbBrowseAppli.
     */
    public JButton getJbBrowseAppli() {
        return jbBrowseAppli;
    }

    /**
     * @return jbDelete.
     */
    public JButton getJbDelete() {
        return jbDelete;
    }

    /**
     * @return pathRadioButton.
     */
    public JRadioButton getPathRadioButton() {
        return pathRadioButton;
    }

    /**
     * @return urlRadioButton.
     */
    public JRadioButton getUrlRadioButton() {
        return urlRadioButton;
    }

    /**
     * @return applicationList.
     */
    public JList getApplicationList() {
        return applicationList;
    }

    /**
     * @return applicationsItems.
     */
    public Vector<String> getApplicationsItems() {
        return applicationsItems;
    }

    /**
     * @return errorLabel.
     */
    public JLabel getErrorLabel() {
        return errorLabel;
    }

    /**
     * Set the error value.
     * @param errorLabel the error label value.
     */
    public void setErrorLabel(final JLabel errorLabel) {
        this.errorLabel = errorLabel;
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        jbBrowseAppli.addActionListener(listener);
        jbAdd.addActionListener(listener);
        jbDelete.addActionListener(listener);
        urlRadioButton.addActionListener(listener);
        pathRadioButton.addActionListener(listener);
    }
}
