/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BuildSummaryFrame.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.awt.event.KeyListener;
import java.util.Vector;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with BuildSummaryFrame fields.
 * @author skabore
 */
public class BuildSummaryFrame extends JPanel {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -6613996049403464361L;

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The starter name label.
     */
    private JLabel starterNameLabel;

    /**
     * The starter location label.
     */
    private JLabel starterLocationLabel;

    /**
     * The starter path label.
     */
    private JLabel starterPathLabel;

    /**
     * The starter path.
     */
    private JLabel starterPath;

    /**
     * The label.
     */
    private JLabel label;

    /**
     * The error label.
     */
    private JLabel errorLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The starter name textfield.
     */
    private JTextField starterName;

    /**
     * The starter location textfield.
     */
    private JTextField starterLocation;

    /**
     * The starter location browse button.
     */
    private JButton jbBrowseStarterLocation;

    /**
     * The application list.
     */
    private static JList applicationList;

    /**
     * The application item.
     */
    private static Vector<String> applicationsItems;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * The useJonasFullStarter CheckBox.
     */
    private JCheckBox useJonasFullStarter;

    /**
     * The Starter JAR file name.
     */
    private String starterJarFileName;

    /**
     * The Starter JAR file location.
     */
    private String starterJarFileLocation;

    /**
     * The constructor.
     * @param starterJarFileLocation the starter Jar file location.
     * @param starterJarFileName the starter Jar file name.
     * @param steps, the required steps to create a starter
     */
    public BuildSummaryFrame(final String starterJarFileLocation, final String starterJarFileName, final int steps) {

        super();
        this.steps = steps;
        this.starterJarFileLocation = starterJarFileLocation;
        this.starterJarFileName = starterJarFileName;

        this.contentPanel = getContentPanel();
        this.contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        this.titlePanel = new javax.swing.JPanel();
        this.textLabel = new javax.swing.JLabel();
        this.iconLabel = new javax.swing.JLabel();
        this.separator = new javax.swing.JSeparator();

        setLayout(new java.awt.BorderLayout());

        this.titlePanel.setLayout(new java.awt.BorderLayout());
        this.titlePanel.setBackground(Color.gray);

        this.textLabel.setBackground(Color.gray);
        this.textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        this.textLabel.setText("Local JOnAS server folder");
        this.textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        this.textLabel.setOpaque(true);

        this.iconLabel.setBackground(Color.gray);
        if (icon != null) {
            this.iconLabel.setIcon(icon);
        }

        this.titlePanel.add(this.textLabel, BorderLayout.CENTER);
        this.titlePanel.add(new JLabel("7/" + this.steps + "  "), BorderLayout.EAST);
        this.titlePanel.add(this.separator, BorderLayout.SOUTH);

        add(this.titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(this.contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel(new BorderLayout());

        this.starterLocation = new JTextField(53);
        this.starterName = new JTextField();
        this.starterName.setPreferredSize(new Dimension(10, 25));
        this.starterLocation.setPreferredSize(new Dimension(70, 25));
        this.jbBrowseStarterLocation = new JButton("Browse...");
        this.starterLocationLabel = new JLabel("Starter location ", SwingConstants.TRAILING);
        this.starterNameLabel = new JLabel("Starter name ", SwingConstants.TRAILING);
        this.starterPathLabel = new JLabel("Path: ", SwingConstants.TRAILING);
        this.starterPath = new JLabel();
        this.starterPath.setFont(new Font("MS Sans Serif", Font.ITALIC, 11));

        String fileSeparator = System.getProperty("file.separator");
        this.starterName.setText(this.starterJarFileName);
        this.starterLocation.setText(this.starterJarFileLocation);
        this.starterPath.setText(this.starterJarFileLocation + fileSeparator + this.starterName.getText());

        this.label = new JLabel("Set the fields by choosing a valid" + " JOnAS Root folder");
        this.label.setPreferredSize(new Dimension(10, 25));
        this.errorLabel = new JLabel("5");
        this.errorLabel.setForeground(Color.red);
        this.useJonasFullStarter = new JCheckBox("Create JOnAS Starter" + " with JOnAS Full Starter."
                + " (Allow JOnAS server configuration)", false);

        contentPanel1.add(createSummaryPanel(), BorderLayout.CENTER);
        contentPanel1.add(this.errorLabel, BorderLayout.SOUTH);
        return contentPanel1;
    }

    /**
     * Create panel based on the Summary fields.
     * @return contentPanel
     */
    private JPanel createSummaryPanel() {
        JPanel content = new JPanel(new BorderLayout());
        JPanel content2 = new JPanel(new BorderLayout());
        JPanel applicationPanel = new JPanel(new SpringLayout());
        JPanel starterLocationPanel = new JPanel(new BorderLayout());
        JPanel createWithFullStarterPanel = new JPanel(new BorderLayout());
        JPanel applicationSummaryPanel = new JPanel(new BorderLayout());
        JPanel applicationListPanel = new JPanel(new BorderLayout());

        applicationsItems = new Vector<String>();
        applicationList = new JList(applicationsItems);
        JScrollPane applicationPane = new JScrollPane(applicationList);
        applicationPane.setPreferredSize(new Dimension(450, 200));

        createWithFullStarterPanel.add(new JLabel(" "), BorderLayout.NORTH);
        createWithFullStarterPanel.add(this.useJonasFullStarter, BorderLayout.CENTER);
        createWithFullStarterPanel.add(new JLabel(" "), BorderLayout.SOUTH);

        applicationSummaryPanel.add(new JLabel("List of applications "), BorderLayout.NORTH);
        applicationSummaryPanel.add(applicationPane, BorderLayout.CENTER);

        applicationListPanel.add(createWithFullStarterPanel, BorderLayout.NORTH);
        applicationListPanel.add(applicationSummaryPanel, BorderLayout.CENTER);
        applicationListPanel.add(new JLabel(" "), BorderLayout.SOUTH);

        applicationPanel.add(this.starterNameLabel);
        this.starterNameLabel.setLabelFor(this.starterName);
        applicationPanel.add(this.starterName);

        applicationPanel.add(this.starterLocationLabel);
        this.starterLocationLabel.setLabelFor(this.starterLocation);
        starterLocationPanel.add(this.starterLocation, BorderLayout.CENTER);
        starterLocationPanel.add(this.jbBrowseStarterLocation, BorderLayout.EAST);
        applicationPanel.add(starterLocationPanel);

        SpringUtilities.makeCompactGrid(applicationPanel, 2, 2, 6, 6, 6, 6);

        JPanel startPathPanel = new JPanel(new SpringLayout());
        startPathPanel.add(this.starterPathLabel);
        this.starterPathLabel.setLabelFor(this.starterPath);
        startPathPanel.add(this.starterPath);
        startPathPanel.add(new JLabel(""));
        startPathPanel.add(new JLabel(""));
        SpringUtilities.makeCompactGrid(startPathPanel, 2, 2, 6, 6, 6, 6);

        content2.add(this.label, BorderLayout.NORTH);
        content2.add(applicationPanel, BorderLayout.CENTER);
        content2.add(startPathPanel, BorderLayout.SOUTH);

        content.add(applicationListPanel, BorderLayout.NORTH);
        content.add(content2, BorderLayout.CENTER);
        content.add(this.errorLabel, BorderLayout.SOUTH);
        return content;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return jbBrowseStarterLocation
     */
    public JButton getJbBrowseStarterLocation() {
        return this.jbBrowseStarterLocation;
    }

    /**
     * @return starterLocation
     */
    public JTextField getStarterLocation() {
        return this.starterLocation;
    }

    /**
     * @return starterLocationLabel
     */
    public JLabel getStarterLocationLabel() {
        return this.starterLocationLabel;
    }

    /**
     * @return starterName
     */
    public JTextField getStarterName() {
        return this.starterName;
    }

    /**
     * @return starterNameLabel
     */
    public JLabel getStarterNameLabel() {
        return this.starterNameLabel;
    }

    /**
     * @return label
     */
    public JLabel getLabel() {
        return this.label;
    }

    /**
     * @return errorLabel
     */
    public JLabel getErrorLabel() {
        return this.errorLabel;
    }

    /**
     * @return useJonasFullStarter value.
     */
    public JCheckBox getUseJonasFullStarter() {
        return this.useJonasFullStarter;
    }

    /**
     * @return starterPath
     */
    public JLabel getStarterPath() {
        return this.starterPath;
    }

    /**
     * @return starterPathLabel
     */
    public JLabel getStarterPathLabel() {
        return this.starterPathLabel;
    }

    /**
     * @return applicationsItems.
     */
    public static Vector<String> getApplicationsItems() {
        return applicationsItems;
    }

    /**
     * @return applicationList.
     */
    public static JList getApplicationList() {
        return applicationList;
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        this.jbBrowseStarterLocation.addActionListener(listener);
        this.useJonasFullStarter.addActionListener(listener);
    }

    /**
     * Add keyListener to the textfileds.
     * @param keyListener the keyListener.
     */
    @Override
    public void addKeyListener(final KeyListener keyListener) {
        this.starterLocation.addKeyListener(keyListener);
        this.starterName.addKeyListener(keyListener);
    }
}
