/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RunningJonasFieldFromDiskFrame.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.awt.event.KeyListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with RunningJonasFieldFromDiskFrame fields.
 * @author skabore
 */
public class RunningJonasFieldFromDiskFrame extends JPanel {

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The label.
     */
    private JLabel label;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The error label.
     */
    private JLabel errorLabel;

    /**
     * The JOnAS root label.
     */
    private JLabel jonasRootLabel;

    /**
     * The JOnAS base label.
     */
    private JLabel jonasBaseLabel;

    /**
     * The Java home label.
     */
    private JLabel javaHomeLabel;

    /**
     * The JOnAS root textfield.
     */
    private JTextField jonasRoot;

    /**
     * The JOnAS base textfield.
     */
    private JTextField jonasBase;

    /**
     * The Java home textfield.
     */
    private JTextField javaHome;

    /**
     * The use JOnAS base checkBox.
     */
    private JCheckBox useJonasBase;

    /**
     * The JOnAS root browse button.
     */
    private JButton jbBrowseJonasRoot;

    /**
     * The JOnAS base browse button.
     */
    private JButton jbBrowseJonasBase;

    /**
     * The Java home browse button.
     */
    private JButton jbBrowseJavaHome;

    /**
     * The default constructor.
     * @param starter the starter librairy
     * @param steps, the required steps to create a starter
     * @param stepId, the sted number
     */
    public RunningJonasFieldFromDiskFrame(final int steps, final int stepId) {
        super();
        this.contentPanel = getContentPanel();
        this.contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        this.titlePanel = new javax.swing.JPanel();
        this.textLabel = new javax.swing.JLabel();
        this.iconLabel = new javax.swing.JLabel();
        this.separator = new javax.swing.JSeparator();

        setLayout(new java.awt.BorderLayout());

        this.titlePanel.setLayout(new java.awt.BorderLayout());
        this.titlePanel.setBackground(Color.gray);

        this.textLabel.setBackground(Color.gray);
        this.textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        this.textLabel.setText("Local JOnAS server folder");
        this.textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        this.textLabel.setOpaque(true);

        this.iconLabel.setBackground(Color.gray);
        if (icon != null) {
            this.iconLabel.setIcon(icon);
        }

        this.titlePanel.add(this.textLabel, BorderLayout.CENTER);
        this.titlePanel.add(new JLabel(stepId + "/" + steps + "   "), BorderLayout.EAST);
        this.titlePanel.add(this.separator, BorderLayout.SOUTH);

        add(this.titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(this.contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel(new BorderLayout());

        this.useJonasBase = new JCheckBox("Use private configuration folder" + " (JOnAS Base)");//
        this.javaHome = new JTextField(System.getenv("JAVA_HOME"), 50);
        this.jonasRoot = new JTextField();
        this.jonasBase = new JTextField();
        this.jbBrowseJonasRoot = new JButton("Browse...");
        this.jbBrowseJonasBase = new JButton("Browse...");
        this.jbBrowseJavaHome = new JButton("Browse...");
        this.jonasRootLabel = new JLabel("JOnAS Root ", SwingConstants.TRAILING);
        this.jonasBaseLabel = new JLabel("JOnAS Base ", SwingConstants.TRAILING);
        this.javaHomeLabel = new JLabel("  Java home ", SwingConstants.TRAILING);
        this.label = new JLabel("Set the fields by choosing a valid JOnAS Root" + " folder");
        this.errorLabel = new JLabel();
        this.errorLabel.setForeground(Color.red);
        contentPanel1.add(createFromDiskPanel(), BorderLayout.CENTER);
        contentPanel1.add(this.errorLabel, BorderLayout.SOUTH);
        return contentPanel1;
    }

    /**
     * Create panel based on the FromDisk option.
     * @return contentPanel
     */
    private JPanel createFromDiskPanel() {
        JPanel content = new JPanel();
        JPanel applicationPanel = new JPanel(new SpringLayout());
        JPanel javaHomePanel = new JPanel(new SpringLayout());
        JPanel javaHomeFieldPanel = new JPanel(new SpringLayout());
        JPanel jonasRootPanel = new JPanel(new SpringLayout());
        JPanel jonasRootFieldPanel = new JPanel(new SpringLayout());
        JPanel jonasBasePanel = new JPanel(new SpringLayout());
        JPanel jonasBaseFieldPanel = new JPanel(new SpringLayout());

        this.javaHomeLabel.setLabelFor(this.javaHome);
        javaHomeFieldPanel.add(this.javaHome);
        javaHomeFieldPanel.add(this.jbBrowseJavaHome);
        SpringUtilities.makeCompactGrid(javaHomeFieldPanel, 1, 2, 6, 0, 6, 0);
        javaHomePanel.add(this.javaHomeLabel);
        javaHomePanel.add(javaHomeFieldPanel);
        SpringUtilities.makeCompactGrid(javaHomePanel, 1, 2, 6, 6, 6, 6);

        this.jonasRootLabel.setLabelFor(this.jonasRoot);
        jonasRootFieldPanel.add(this.jonasRoot);
        jonasRootFieldPanel.add(this.jbBrowseJonasRoot);
        SpringUtilities.makeCompactGrid(jonasRootFieldPanel, 1, 2, 6, 0, 6, 0);
        jonasRootPanel.add(this.jonasRootLabel);
        jonasRootPanel.add(jonasRootFieldPanel);
        SpringUtilities.makeCompactGrid(jonasRootPanel, 1, 2, 6, 6, 6, 6);

        this.jonasBaseLabel.setLabelFor(this.jonasBase);
        jonasBaseFieldPanel.add(this.jonasBase);
        jonasBaseFieldPanel.add(this.jbBrowseJonasBase);
        SpringUtilities.makeCompactGrid(jonasBaseFieldPanel, 1, 2, 6, 0, 6, 0);
        jonasBasePanel.add(this.jonasBaseLabel);
        jonasBasePanel.add(jonasBaseFieldPanel);
        SpringUtilities.makeCompactGrid(jonasBasePanel, 1, 2, 6, 6, 6, 6);
        showJonasBaseField(false);

        applicationPanel.add(this.label);
        applicationPanel.add(new JLabel(""));
        applicationPanel.add(javaHomePanel);
        applicationPanel.add(jonasRootPanel);
        applicationPanel.add(this.useJonasBase);
        applicationPanel.add(jonasBasePanel);
        SpringUtilities.makeCompactGrid(applicationPanel, 6, 1, 6, 6, 6, 6);

        content.add(applicationPanel);
        return content;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return jbBrowseJavaHome
     */
    public JButton getJbBrowseJavaHome() {
        return this.jbBrowseJavaHome;
    }

    /**
     * @return jbBrowseJonasBase
     */
    public JButton getJbBrowseJonasBase() {
        return this.jbBrowseJonasBase;
    }

    /**
     * @return jbBrowseJonasRoot
     */
    public JButton getJbBrowseJonasRoot() {
        return this.jbBrowseJonasRoot;
    }

    /**
     * @return javaHome
     */
    public JTextField getJavaHome() {
        return this.javaHome;
    }

    /**
     * @return jonasBase
     */
    public JTextField getJonasBase() {
        return this.jonasBase;
    }

    /**
     * @return javaHomeLabel
     */
    public JLabel getJavaHomeLabel() {
        return this.javaHomeLabel;
    }

    /**
     * @return jonasBaseLabel
     */
    public JLabel getJonasBaseLabel() {
        return this.jonasBaseLabel;
    }

    /**
     * @return jonasRoot
     */
    public JTextField getJonasRoot() {
        return this.jonasRoot;
    }

    /**
     * @return jonasRootLabel
     */
    public JLabel getJonasRootLabel() {
        return this.jonasRootLabel;
    }

    /**
     * @return label
     */
    public JLabel getLabel() {
        return this.label;
    }

    /**
     * @return errorLabel
     */
    public JLabel getErrorLabel() {
        return this.errorLabel;
    }

    /**
     * @return useJonasBase
     */
    public JCheckBox getUseJonasBase() {
        return this.useJonasBase;
    }

    /**
     * Show or hide the JOnAS Base fields.
     * @param enable if true JOnAS Base fields are showed, hided otherwise.
     */
    public void showJonasBaseField(final boolean enable) {
        this.jonasBase.setVisible(enable);
        this.jbBrowseJonasBase.setVisible(enable);
        this.jonasBaseLabel.setVisible(enable);
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        this.useJonasBase.addActionListener(listener);
        this.jbBrowseJonasRoot.addActionListener(listener);
        this.jbBrowseJonasBase.addActionListener(listener);
        this.jbBrowseJavaHome.addActionListener(listener);
    }

    /**
     * Add keyListener to the textfileds.
     * @param keyListener the keyListener.
     */
    @Override
    public void addKeyListener(final KeyListener keyListener) {
        this.jonasRoot.addKeyListener(keyListener);
        this.jonasBase.addKeyListener(keyListener);
        this.javaHome.addKeyListener(keyListener);
    }
}
